#!/bin/bash

cd tests
FILES=`find -L $DIRS -name '*.opt' | sort`
cd ..

echo "Running tests.."
echo

GOOD=0
INCOMPLETE=0
FAILED=0
TIMEOUT=0
BEGIN_TIME=`date +%s`

for name in $FILES; do
  file=`echo "$name" | cut -d. -f-2`
  echo -n "$file.. "

  START=`date +%s`
  OUTPUT=`./run.sh "tests/$file" $@ 2>&1`
  RES=$?
  END=`date +%s`

  if ( test $RES -eq 0 && echo "$OUTPUT" | grep -q "Z3 returned unknown" ) ; then
    echo -n -e "\033[1;33mINCOMPLETE\033[0m"
    : $(( ++INCOMPLETE ))
  elif ( test $RES -eq 0 && echo "$OUTPUT" | grep -q "Done!" ) ; then
    echo -n -e "\033[1;32mPASSED\033[0m"
    : $(( ++GOOD ))
  elif ( test $RES -eq 137 && echo "$OUTPUT" | grep -q "Killed" ) ; then
    echo -n -e "\033[1;33mTIMEOUT\033[0m"
    : $(( ++TIMEOUT ))
  else
    echo -n -e "\033[1;31mFAILED\033[0m"
    : $(( ++FAILED ))
  fi

  TIME=$(( END-START ))
  echo " (in" `printf "%'8.0f" "$TIME"` "sec)"
done

END_TIME=`date +%s`
TIME=$(( END_TIME-BEGIN_TIME ))

NUMBER_OF_TESTS=$((GOOD + INCOMPLETE + FAILED + TIMEOUT + MEMORY))
PERCENT=$((GOOD * 100 / NUMBER_OF_TESTS))

echo
echo "passed ${GOOD} out of ${NUMBER_OF_TESTS} tests (${PERCENT}%)"
echo "timeout: ${TIMEOUT}"

echo "Total time:" `printf "%'8.0f" "$TIME"` "seconds"


if [ $GOOD -ne $NUMBER_OF_TESTS ] ; then
  exit 1
fi
